@@ -1,4 +1,4 @@
-from object import *
+from ..object import *
 import asyncio
 import requests
 from enum import Enum
